{%- set author = authors | first -%}

{% block title %}
## {{ role.name }}
{% endblock %}

{% block ansigenome_managed %}
<!-- This file was generated by Ansigenome. Do not edit this file directly but
     instead have a look at the files in the ./meta/ directory. -->
{% endblock %}

{% block badges %}
{% if ansigenome_info.travis|d() %}
[![Travis CI](http://img.shields.io/travis/{{ scm.user + '/' + role.slug }}.svg?style=flat)](http://travis-ci.org/{{ scm.user + '/' + role.slug }})
{% endif %}
{% if ansigenome_info.galaxy_id|d() %}
[![Ansible Galaxy](http://img.shields.io/badge/galaxy-{{ role.galaxy_name | replace('-', '--')}}-660198.svg?style=flat)](https://galaxy.ansible.com/detail#/role/{{ ansigenome_info.galaxy_id }})
{% endif %}
{% if galaxy_info.platforms|d() %}
[![Platforms](http://img.shields.io/badge/platforms-{{ galaxy_info.platforms | map(attribute='name') | sort | join('%20/%20') | lower }}-lightgrey.svg?style=flat)](#)
{% endif %}
{%- endblock %}

{% if ansigenome_info.status|d() is mapping or ansigenome_info.beta|d() %}
{% block status %}
{# Consider using the `ansigenome_info.status` instead of `ansigenome_info.beta` #}

{% if ansigenome_info.status|d() and ansigenome_info.status.name|d('beta') == 'deprecated' %}
{% block deprecated %}
### Warning, this is a deprecated role
{% endblock %}
{% elif ansigenome_info.beta|d() or ansigenome_info.status.name|d('beta') == 'beta' %}
{% block beta %}
### Warning, this is a Beta role

This role has been marked by the author as a beta role, which means that it
might be significantly changed in the future. Be careful while using this role
in a production environment.
{% endblock %}
{% endif %}
{% if ansigenome_info.status|d() and ansigenome_info.status.note|d('') %}

{{ ansigenome_info.status.note }}
{% endif %}

***
{% endblock %}
{% endif %}

{% if ansigenome_info.synopsis|d() %}
{% block synopsis %}
{{ ansigenome_info.synopsis | trim }}
{% endblock %}
{% endif %}

{% if ansigenome_info.galaxy_id|d() %}
{% block installation %}
### Installation

This role requires at least Ansible{% if galaxy_info.min_ansible_version|d() %} `v{{ galaxy_info.min_ansible_version }}`{% endif %}. To install it, run:

```Shell
ansible-galaxy install {{ role.galaxy_name }}
```
{% endblock %}
{% endif %}

{% if dependencies|d() -%}
{% block dependencies %}
### Role dependencies

{% for role_dependency_name in dependencies | map(attribute='role') | unique %}
- `{{ role_dependency_name | trim }}`
{% endfor %}
{% endblock %}
{% endif %}
{% block standalone %}
{% endblock %}
{% if ansigenome_info.defaults|d() %}
{% block defaults %}

### Role variables

List of default variables available in the inventory:

```YAML
{{ ansigenome_info.defaults | trim }}
```
{% endblock %}
{% endif %}

{% if ansigenome_info.facts|d() %}
{% block facts %}
List of internal variables used by the role:

{{ ansigenome_info.facts | trim | indent(4, true) }}{% endblock %}{% endif %}

{% if ansigenome_info.usage|d() %}
{% block usage %}
### Detailed usage guide

{{ ansigenome_info.usage | trim }}
{% endblock %}
{% endif %}

{% if ansigenome_info.custom|d() %}

{{ ansigenome_info.custom | trim }}{% endif %}

{% block authors %}
### Authors and license

`{{ role.name }}` role was written by:

{% for credit in authors %}
- {{ "[" if credit.url|d() else "" }}{{ credit.name }}{{ "](" + credit.url + ")" if credit.url|d() else "" }}{% if credit.email|d() %} | [e-mail](mailto:{{ credit.email }}){% endif %}{% if credit.twitter|d() %} | [Twitter](https://twitter.com/{{ credit.twitter }}){% endif %}{% if credit.github|d() %} | [GitHub](https://github.com/{{ credit.github }}){% endif %}

{% endfor %}

License: [{{ license.type | trim }}]({{ license.url | trim }})
{% endblock %}

{% block footer %}
***

README generated by [Ansigenome](https://github.com/nickjj/ansigenome/).
{% endblock %}
